@@ -18,15 +18,21 @@
 define('AREA', 'admin');
 require './lib/init.php';
 
+use Froxlor\Settings;
+
 if ($userinfo['change_serversettings'] == '1') {
 
-	$customer_tmpdir = '/tmp/';
-	if (Settings::Get('system.mod_fcgid') == '1' && Settings::Get('system.mod_fcgid_tmpdir') != '')
-	{
-		$customer_tmpdir = Settings::Get('system.mod_fcgid_tmpdir');
+	if ($action == 'setconfigured') {
+		Settings::Set('panel.is_configured', '1', true);
+		\Froxlor\UI\Response::redirectTo('admin_configfiles.php', array(
+			's' => $s
+		));
 	}
-	elseif (Settings::Get('phpfpm.enabled') == '1' && Settings::Get('phpfpm.tmpdir') != '')
-	{
+
+	$customer_tmpdir = '/tmp/';
+	if (Settings::Get('system.mod_fcgid') == '1' && Settings::Get('system.mod_fcgid_tmpdir') != '') {
+		$customer_tmpdir = Settings::Get('system.mod_fcgid_tmpdir');
+	} elseif (Settings::Get('phpfpm.enabled') == '1' && Settings::Get('phpfpm.tmpdir') != '') {
 		$customer_tmpdir = Settings::Get('phpfpm.tmpdir');
 	}
 
@@ -36,7 +42,7 @@ if ($userinfo['change_serversettings'] == '1') {
 		$nameservers = explode(',', Settings::Get('system.nameservers'));
 		foreach ($nameservers as $nameserver) {
 			$nameserver = trim($nameserver);
-			$nameserver_ips = gethostbynamel($nameserver);
+			$nameserver_ips = \Froxlor\PhpHelper::gethostbynamel6($nameserver);
 			if (is_array($nameserver_ips) && count($nameserver_ips) > 0) {
 				$ns_ips .= implode(",", $nameserver_ips);
 			}
@@ -58,12 +64,12 @@ if ($userinfo['change_serversettings'] == '1') {
 		'<VIRTUAL_UID_MAPS>' => Settings::Get('system.vmail_uid'),
 		'<VIRTUAL_GID_MAPS>' => Settings::Get('system.vmail_gid'),
 		'<SSLPROTOCOLS>' => (Settings::Get('system.use_ssl') == '1') ? 'imaps pop3s' : '',
-		'<CUSTOMER_TMP>' => makeCorrectDir($customer_tmpdir),
-		'<BASE_PATH>' => makeCorrectDir(FROXLOR_INSTALL_DIR),
-		'<BIND_CONFIG_PATH>' => makeCorrectDir(Settings::Get('system.bindconf_directory')),
+		'<CUSTOMER_TMP>' => \Froxlor\FileDir::makeCorrectDir($customer_tmpdir),
+		'<BASE_PATH>' => \Froxlor\FileDir::makeCorrectDir(\Froxlor\Froxlor::getInstallDir()),
+		'<BIND_CONFIG_PATH>' => \Froxlor\FileDir::makeCorrectDir(Settings::Get('system.bindconf_directory')),
 		'<WEBSERVER_RELOAD_CMD>' => Settings::Get('system.apachereload_command'),
-		'<CUSTOMER_LOGS>' => makeCorrectDir(Settings::Get('system.logfiles_directory')),
-		'<FPM_IPCDIR>' => makeCorrectDir(Settings::Get('phpfpm.fastcgi_ipcdir')),
+		'<CUSTOMER_LOGS>' => \Froxlor\FileDir::makeCorrectDir(Settings::Get('system.logfiles_directory')),
+		'<FPM_IPCDIR>' => \Froxlor\FileDir::makeCorrectDir(Settings::Get('phpfpm.fastcgi_ipcdir')),
 		'<WEBSERVER_GROUP>' => Settings::Get('system.httpgroup')
 	);
 
@@ -79,17 +85,17 @@ if ($userinfo['change_serversettings'] == '1') {
 	$services = "";
 	$daemons = "";
 
-	$config_dir = makeCorrectDir(FROXLOR_INSTALL_DIR . '/lib/configfiles/');
+	$config_dir = \Froxlor\FileDir::makeCorrectDir(\Froxlor\Froxlor::getInstallDir() . '/lib/configfiles/');
 
 	if ($distribution != "") {
 
-		if (!file_exists($config_dir . '/' . $distribution . ".xml")) {
+		if (! file_exists($config_dir . '/' . $distribution . ".xml")) {
 			trigger_error("Unknown distribution, are you playing around with the URL?");
-			exit;
+			exit();
 		}
 
 		// create configparser object
-		$configfiles = new ConfigParser($config_dir . '/' . $distribution . ".xml");
+		$configfiles = new \Froxlor\Config\ConfigParser($config_dir . '/' . $distribution . ".xml");
 
 		// get distro-info
 		$dist_display = getCompleteDistroName($configfiles);
@@ -99,9 +105,9 @@ if ($userinfo['change_serversettings'] == '1') {
 
 		if ($service != "") {
 
-			if (!isset($services[$service])) {
+			if (! isset($services[$service])) {
 				trigger_error("Unknown service, are you playing around with the URL?");
-				exit;
+				exit();
 			}
 
 			$daemons = $services[$service]->getDaemons();
@@ -112,12 +118,12 @@ if ($userinfo['change_serversettings'] == '1') {
 					if ($dd->default) {
 						$title = $title . " (" . strtolower($lng['panel']['default']) . ")";
 					}
-					$daemons_select .= makeoption($title, $di);
+					$daemons_select .= \Froxlor\UI\HTML::makeoption($title, $di);
 				}
 			}
 		} else {
 			foreach ($services as $si => $sd) {
-				$services_select .= makeoption($sd->title, $si);
+				$services_select .= \Froxlor\UI\HTML::makeoption($sd->title, $si);
 			}
 		}
 	} else {
@@ -129,7 +135,7 @@ if ($userinfo['change_serversettings'] == '1') {
 		// read in all the distros
 		foreach ($distros as $_distribution) {
 			// get configparser object
-			$dist = new ConfigParser($_distribution);
+			$dist = new \Froxlor\Config\ConfigParser($_distribution);
 			// get distro-info
 			$dist_display = getCompleteDistroName($dist);
 			// store in tmp array
@@ -141,15 +147,15 @@ if ($userinfo['change_serversettings'] == '1') {
 
 		foreach ($distributions_select_data as $dist_display => $dist_index) {
 			// create select-box-option
-			$distributions_select .= makeoption($dist_display, $dist_index);
+			$distributions_select .= \Froxlor\UI\HTML::makeoption($dist_display, $dist_index);
 		}
 	}
 
 	if ($distribution != "" && $service != "" && $daemon != "") {
 
-		if (!isset($daemons[$daemon])) {
+		if (! isset($daemons[$daemon])) {
 			trigger_error("Unknown daemon, are you playing around with the URL?");
-			exit;
+			exit();
 		}
 
 		$confarr = $daemons[$daemon]->getConfig();
@@ -164,49 +170,49 @@ if ($userinfo['change_serversettings'] == '1') {
 
 		$lasttype = '';
 		$commands = '';
-		foreach ($confarr as $idx => $action) {
-			if ($lasttype != '' && $lasttype != $action['type']) {
+		foreach ($confarr as $_action) {
+			if ($lasttype != '' && $lasttype != $_action['type']) {
 				$commands = trim($commands);
 				$numbrows = count(explode("\n", $commands));
-				eval("\$configpage.=\"" . getTemplate("configfiles/configfiles_commands") . "\";");
+				eval("\$configpage.=\"" . \Froxlor\UI\Template::getTemplate("configfiles/configfiles_commands") . "\";");
 				$lasttype = '';
 				$commands = '';
 			}
-			switch ($action['type']) {
+			switch ($_action['type']) {
 				case "install":
-					$commands .= strtr($action['content'], $replace_arr) . "\n";
+					$commands .= strtr($_action['content'], $replace_arr) . "\n";
 					$lasttype = "install";
 					break;
 				case "command":
-					$commands .= strtr($action['content'], $replace_arr) . "\n";
+					$commands .= strtr($_action['content'], $replace_arr) . "\n";
 					$lasttype = "command";
 					break;
 				case "file":
-					if (array_key_exists('content', $action)) {
-						$commands_file = getFileContentContainer($action['content'], $replace_arr, $action['name'], $distro_editor);
-					} elseif (array_key_exists('subcommands', $action)) {
-						foreach ($action['subcommands'] as $fileaction) {
+					if (array_key_exists('content', $_action)) {
+						$commands_file = getFileContentContainer($_action['content'], $replace_arr, $_action['name'], $distro_editor);
+					} elseif (array_key_exists('subcommands', $_action)) {
+						foreach ($_action['subcommands'] as $fileaction) {
 							if (array_key_exists('execute', $fileaction) && $fileaction['execute'] == "pre") {
 								$commands_pre .= $fileaction['content'] . "\n";
 							} elseif (array_key_exists('execute', $fileaction) && $fileaction['execute'] == "post") {
 								$commands_post .= $fileaction['content'] . "\n";
 							} elseif ($fileaction['type'] == 'file') {
-								$commands_file = getFileContentContainer($fileaction['content'], $replace_arr, $action['name'], $distro_editor);
+								$commands_file = getFileContentContainer($fileaction['content'], $replace_arr, $_action['name'], $distro_editor);
 							}
 						}
 					}
-					$realname = $action['name'];
+					$realname = $_action['name'];
 					$commands = trim($commands_pre);
 					if ($commands != "") {
 						$numbrows = count(explode("\n", $commands));
-						eval("\$commands_pre=\"" . getTemplate("configfiles/configfiles_commands") . "\";");
+						eval("\$commands_pre=\"" . \Froxlor\UI\Template::getTemplate("configfiles/configfiles_commands") . "\";");
 					}
 					$commands = trim($commands_post);
 					if ($commands != "") {
 						$numbrows = count(explode("\n", $commands));
-						eval("\$commands_post=\"" . getTemplate("configfiles/configfiles_commands") . "\";");
+						eval("\$commands_post=\"" . \Froxlor\UI\Template::getTemplate("configfiles/configfiles_commands") . "\";");
 					}
-					eval("\$configpage.=\"" . getTemplate("configfiles/configfiles_subfileblock") . "\";");
+					eval("\$configpage.=\"" . \Froxlor\UI\Template::getTemplate("configfiles/configfiles_subfileblock") . "\";");
 					$commands = '';
 					$commands_pre = '';
 					$commands_post = '';
@@ -216,15 +222,17 @@ if ($userinfo['change_serversettings'] == '1') {
 		$commands = trim($commands);
 		if ($commands != '') {
 			$numbrows = count(explode("\n", $commands));
-			eval("\$configpage.=\"" . getTemplate("configfiles/configfiles_commands") . "\";");
+			eval("\$configpage.=\"" . \Froxlor\UI\Template::getTemplate("configfiles/configfiles_commands") . "\";");
 		}
-		eval("echo \"" . getTemplate("configfiles/configfiles") . "\";");
+		eval("echo \"" . \Froxlor\UI\Template::getTemplate("configfiles/configfiles") . "\";");
 	} else {
-		eval("echo \"" . getTemplate("configfiles/wizard") . "\";");
+		$basedir = \Froxlor\Froxlor::getInstallDir();
+		eval("echo \"" . \Froxlor\UI\Template::getTemplate("configfiles/wizard") . "\";");
 	}
 } else {
-	die('not allowed to see this page');
-	// redirect or similar here
+	\Froxlor\UI\Response::redirectTo('admin_index.php', array(
+		's' => $s
+	));
 }
 
 // helper functions
@@ -236,7 +244,7 @@ function getFileContentContainer($file_content, &$replace_arr, $realname, $distr
 		$file_content = strtr($file_content, $replace_arr);
 		$file_content = htmlspecialchars($file_content);
 		$numbrows = count(explode("\n", $file_content));
-		eval("\$files=\"" . getTemplate("configfiles/configfiles_file") . "\";");
+		eval("\$files=\"" . \Froxlor\UI\Template::getTemplate("configfiles/configfiles_file") . "\";");
 	}
 	return $files;
 }
