@@ -14,7 +14,6 @@
  * @package    Formfields
  *
  */
-
 return array(
 	'emails_edit' => array(
 		'title' => $lng['emails']['emails_edit'],
@@ -34,29 +33,29 @@ return array(
 						'visible' => ($result['popaccountid'] != 0 ? true : false),
 						'label' => $lng['emails']['account'],
 						'type' => 'label',
-						'value' => $lng['panel']['yes'].'&nbsp;[<a href="'.$filename.'?page=accounts&amp;action=changepw&amp;id='.$result['id'].'&amp;s='.$s.'">'.$lng['menue']['main']['changepassword'].'</a>] [<a href="'.$filename.'?page=accounts&amp;action=delete&amp;id='.$result['id'].'&amp;s='.$s.'">'.$lng['emails']['account_delete'].'</a>]'
+						'value' => $lng['panel']['yes'] . '&nbsp;[<a href="' . $filename . '?page=accounts&amp;action=changepw&amp;id=' . $result['id'] . '&amp;s=' . $s . '">' . $lng['menue']['main']['changepassword'] . '</a>] [<a href="' . $filename . '?page=accounts&amp;action=delete&amp;id=' . $result['id'] . '&amp;s=' . $s . '">' . $lng['emails']['account_delete'] . '</a>]'
 					),
 					'account_no' => array(
 						'visible' => ($result['popaccountid'] == 0 ? true : false),
 						'label' => $lng['emails']['account'],
 						'type' => 'label',
-						'value' => $lng['panel']['no'].'&nbsp;[<a href="'.$filename.'?page=accounts&amp;action=add&amp;id='.$result['id'].'&amp;s='.$s.'">'.$lng['emails']['account_add'].'</a>]'
+						'value' => $lng['panel']['no'] . '&nbsp;[<a href="' . $filename . '?page=accounts&amp;action=add&amp;id=' . $result['id'] . '&amp;s=' . $s . '">' . $lng['emails']['account_add'] . '</a>]'
 					),
 					'mail_quota' => array(
-						'visible' => ($result['popaccountid'] != 0 && Settings::Get('system.mail_quota_enabled')),
+						'visible' => ($result['popaccountid'] != 0 && \Froxlor\Settings::Get('system.mail_quota_enabled')),
 						'label' => $lng['customer']['email_quota'],
 						'type' => 'label',
-						'value' => $result['quota'].' MiB [<a href="'.$filename.'?page=accounts&amp;action=changequota&amp;id='.$result['id'].'&amp;s='.$s.'">'.$lng['emails']['quota_edit'].'</a>]'
+						'value' => $result['quota'] . ' MiB [<a href="' . $filename . '?page=accounts&amp;action=changequota&amp;id=' . $result['id'] . '&amp;s=' . $s . '">' . $lng['emails']['quota_edit'] . '</a>]'
 					),
 					'mail_catchall' => array(
 						'label' => $lng['emails']['catchall'],
 						'type' => 'label',
-						'value' => ($result['iscatchall'] == 0 ? $lng['panel']['no'] : $lng['panel']['yes']).' [<a href="'.$filename.'?page='.$page.'&amp;action=togglecatchall&amp;id='.$result['id'].'&amp;s='.$s.'">'.$lng['panel']['toggle'].'</a>]'
+						'value' => ($result['iscatchall'] == 0 ? $lng['panel']['no'] : $lng['panel']['yes']) . ' [<a href="' . $filename . '?page=' . $page . '&amp;action=togglecatchall&amp;id=' . $result['id'] . '&amp;s=' . $s . '">' . $lng['panel']['toggle'] . '</a>]'
 					),
 					'mail_fwds' => array(
-						'label' => $lng['emails']['forwarders'].' ('.$forwarders_count.')',
+						'label' => $lng['emails']['forwarders'] . ' (' . $forwarders_count . ')',
 						'type' => 'label',
-						'value' => $forwarders.' <a href="'.$filename.'?page=forwarders&amp;action=add&amp;id='.$result['id'].'&amp;s='.$s.'">'.$lng['emails']['forwarder_add'].'</a>'
+						'value' => $forwarders . ' <a href="' . $filename . '?page=forwarders&amp;action=add&amp;id=' . $result['id'] . '&amp;s=' . $s . '">' . $lng['emails']['forwarder_add'] . '</a>'
 					)
 				)
 			)
