@@ -16,7 +16,6 @@
  * @package    System
  *
  */
-
 define('TABLE_FTP_GROUPS', 'ftp_groups');
 define('TABLE_FTP_USERS', 'ftp_users');
 define('TABLE_FTP_QUOTALIMITS', 'ftp_quotalimits');
@@ -41,8 +40,6 @@ define('TABLE_PANEL_DISKSPACE', 'panel_diskspace');
 define('TABLE_PANEL_DISKSPACE_ADMINS', 'panel_diskspace_admins');
 define('TABLE_PANEL_LANGUAGE', 'panel_languages');
 define('TABLE_PANEL_IPSANDPORTS', 'panel_ipsandports');
-define('TABLE_PANEL_TICKETS', 'panel_tickets');
-define('TABLE_PANEL_TICKET_CATS', 'panel_ticket_categories');
 define('TABLE_PANEL_LOG', 'panel_syslog');
 define('TABLE_PANEL_PHPCONFIGS', 'panel_phpconfigs');
 define('TABLE_PANEL_CRONRUNS', 'cronjobs_run');
@@ -53,5 +50,6 @@ define('TABLE_DOMAINTOIP', 'panel_domaintoip');
 define('TABLE_DOMAIN_DNS', 'domain_dns_entries');
 define('TABLE_PANEL_FPMDAEMONS', 'panel_fpmdaemons');
 define('TABLE_PANEL_PLANS', 'panel_plans');
+define('TABLE_API_KEYS', 'api_keys');
 
-require dirname(__FILE__).'/version.inc.php';
+require dirname(__FILE__) . '/version.inc.php';
